/*
  This sketch demonstrates how to scan WiFi networks.
  The API is almost the same as with the WiFi Shield library,
  the most obvious difference being the different file you need to include:
  The MIT License (MIT)
  Copyright (c) 2016 by Daniel Eichhorn
*/
#include "WiFi.h"
//Include the correct display library
//For a connection via I2C using Wire include
#include <Wire.h>// Only needed for Arduino 1.6.5 and earlier
#include "SSD1306.h" //alias for `#include "SSD1306Wire.h"`
//or #include "SH1106.h" alis for `#include "SH1106Wire.h"`
//For a connection via I2C using brzo_i2c (must be installed) include
//#include <brzo_i2c.h> //Only needed for Arduino 1.6.5 and earlier
//#include "SSD1306Brzo.h"
//#include "SH1106Brzo.h"
/*For a connection via SPI include
  //#include <SPI.h> // Only needed for Arduino 1.6.5 and earlier
  //#include "SSD1306Spi.h"
  //#include "SH1106SPi.h"
  //initialize the OLED display using SPI
  HSPI pins:
  OLED display      ESP32
  VCC               3V3 or Vin
  GND               G
  SCL/SCK/CLK       GPIO 14
  SDA /MOSI (DOUT)  GPIO 13
  CS                GPIO 15
  SDO /MISO         GPIO 12
  RES/RST           GPIO 16
  SA0 (DC or D/C)   GPIO 02

  VSPI pins:
  OLED display      ESP32
  VCC               3V3 or Vin
  GND               G
  SCL/SCK/CLK       GPIO 18
  SDA /MOSI(DOUT)   GPIO 23
  CS                GPIO 5
  SDO /MISO         GPIO 19
  RES/RST           GPIO 16
  SA0 (DC or D/C)   GPIO 02

  //SSD1306Spi        display(RES, DC, CS);
  //SH1106Spi         display(RES, DC);
*/

/*initialize the OLED display using brzo_i2c
  OLED display      ESP32
  SDA /MOSI(DOUT)   GPIO 21
  SCL/SCK/CLK       GPIO 22

  //SSD1306Brzo display(0x3c, SDA, SCL);
  //SH1106Brzo  display(0x3c, SDA, SCL);*/

//initialize the OLED display using Wire library
SSD1306  display(0x3C, 21, 22);//0x3C is I2C address
//SH1106 display(0x3C, 21, 22);

void setup() {
  Serial.begin(115200);//initialise serial communication at 115200 bps
  //set WiFi to station mode and disconnect from an AP if it was previously connected
  WiFi.mode(WIFI_STA);
  WiFi.disconnect();
  delay(100);//set delay for 100 ms
  Serial.println();
  Serial.println("Initial setup done");//print in Serial monitor
  Serial.println();
  //initialising the UI will init the display too.
  display.init();
  display.flipScreenVertically();
  display.setTextAlignment(TEXT_ALIGN_LEFT);//text alignment set to left
  display.setFont(ArialMT_Plain_10);//create more fonts at http://oleddisplay.squix.ch/
}
//****************************************************************************************
void drawWIFIScanResults() {
  display.clear();//clear the display
  int n = WiFi.scanNetworks();//return the number of WiFi networks found
  Serial.println("Scan done");//print in Serial monitor
  display.drawString(0, 0, "Scan done");//print on OLED display
  if (n == 0) //if no WiFi networks found
  {
    Serial.println("no networks found");//print in Serial monitor
    display.drawString(0, 13, "No WiFi networks found");//print on OLED display
  } 
  else 
  {
    Serial.print(n);//print in Serial monitor
    Serial.println(" WiFi networks found");//print in Serial monitor
    display.drawString(0, 13,String(n)+ " WiFi networks found:");//print on OLED display
    for (int k = 1; k <= n ; ) 
    {
    if (k <=2)
    {
    //print SSID and RSSI for each network found on OLED display
    display.drawString(0, k * 13 + 13, String(k) + ": " + String(WiFi.SSID(k - 1)) + " (" + String(WiFi.RSSI(k - 1)) + ")"+String((WiFi.encryptionType(k-1) == WIFI_AUTH_OPEN) ? " " : " *"));
    ++k;
    display.display();//write the buffer to the display
    delay(1000);//set delay for 1 second
    } else
    {
       if (k <=6)
    {
    display.clear();//clear the display       
    display.drawString(0, ((k * 13) - ((k-2)*13)+13)-(k*13), String(k) + ": " + String(WiFi.SSID(k-1)) + " (" + String(WiFi.RSSI(k-1)) + ")");
     ++k;
    display.display();//write the buffer to the display
    delay(1000);//set delay for 1 second
    }
    else
    {
    display.clear();//clear the display       
    display.drawString(0, ((k * 13) - ((k-2)*13)+13)-(k*13), String(k) + ": " + String(WiFi.SSID(k-1)) + " (" + String(WiFi.RSSI(k-1)) + ")");
     ++k;
    display.display();//write the buffer to the display
    delay(1000);//set delay for 1 second
      }
    }
  }
  for (int i = 0; i < n; ++i) {
    //print SSID and RSSI for each network found in Serial Monitor
    Serial.print(i + 1);
    Serial.print(": ");
    Serial.print(WiFi.SSID(i));
    Serial.print(" (");
    Serial.print(WiFi.RSSI(i));
    Serial.print(")");
    Serial.println((WiFi.encryptionType(i) == WIFI_AUTH_OPEN) ? " " : "*");
    delay(10);//set delay for 10 ms
    display.display();//write the buffer to the display
  }
  delay(3000);//wait 3 seconds before scanning again
}
}
void loop() {
  display.clear();//clear the display
  Serial.println("Scan starts...");//print in Serial monitor
  display.drawString(0, 0, "Scan starts...");//print on OLED display
  display.display();//write the buffer to the display
  drawWIFIScanResults();

}

